@@ -221,7 +221,7 @@ class WorkMailClient(BaseClient):
         Alias: str,
         DirectoryId: str = ...,
         ClientToken: str = ...,
-        Domains: Sequence["DomainTypeDef"] = ...,
+        Domains: Sequence[DomainTypeDef] = ...,
         KmsKeyArn: str = ...,
         EnableInteroperability: bool = ...
     ) -> CreateOrganizationResponseTypeDef:
@@ -764,7 +764,7 @@ class WorkMailClient(BaseClient):
         *,
         OrganizationId: str,
         Name: str,
-        FolderConfigurations: Sequence["FolderConfigurationTypeDef"],
+        FolderConfigurations: Sequence[FolderConfigurationTypeDef],
         Id: str = ...,
         Description: str = ...
     ) -> Dict[str, Any]:
@@ -826,7 +826,7 @@ class WorkMailClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workmail/client/#start_mailbox_export_job)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Applies the specified tags to the specified Amazon WorkMail organization
         resource.
@@ -903,7 +903,7 @@ class WorkMailClient(BaseClient):
         OrganizationId: str,
         ResourceId: str,
         Name: str = ...,
-        BookingOptions: "BookingOptionsTypeDef" = ...
+        BookingOptions: BookingOptionsTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Updates data for the resource.
