@@ -79,11 +79,7 @@ class ListAliasesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self,
-        *,
-        OrganizationId: str,
-        EntityId: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, OrganizationId: str, EntityId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAliasesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListAliases.paginate)
@@ -98,7 +94,7 @@ class ListGroupMembersPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, OrganizationId: str, GroupId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, OrganizationId: str, GroupId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListGroupMembersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListGroupMembers.paginate)
@@ -113,7 +109,7 @@ class ListGroupsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, OrganizationId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, OrganizationId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListGroupsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListGroups.paginate)
@@ -128,11 +124,7 @@ class ListMailboxPermissionsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self,
-        *,
-        OrganizationId: str,
-        EntityId: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, OrganizationId: str, EntityId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListMailboxPermissionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListMailboxPermissions.paginate)
@@ -147,7 +139,7 @@ class ListOrganizationsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListOrganizationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListOrganizations.paginate)
@@ -166,7 +158,7 @@ class ListResourceDelegatesPaginator(Boto3Paginator):
         *,
         OrganizationId: str,
         ResourceId: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListResourceDelegatesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListResourceDelegates.paginate)
@@ -181,7 +173,7 @@ class ListResourcesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, OrganizationId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, OrganizationId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListResourcesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListResources.paginate)
@@ -196,7 +188,7 @@ class ListUsersPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, OrganizationId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, OrganizationId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListUsersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#WorkMail.Paginator.ListUsers.paginate)
